==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/activity/messages/pt-BR/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => '<strong>E-Mail</strong> de resumo',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> atividades',
  'Activities' => 'Atividades',
  'Daily' => 'Diáriamente',
  'E-Mail Summaries' => 'E-mails de resumo',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'E-mails de resumo são enviados para informa-lo sobre atividades recentes na rede.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'E-mails de resumo são enviados para usuários para informa-los sobre atividades recentes em sua rede.',
  'Exclude spaces below from the mail summary' => 'Exclua espaços abaixo do resumo do e-mail',
  'Hourly' => 'De hora em hora',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas notícias',
  'Monthly' => 'Mensal',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Nessa página você pode configurar os conteúdos e o intervalo das atualizações de e-mail.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Nessa página você pode definir o comportamento padrão para seus usuários. Essas configurações podem ser sobrescritas pelos usuários na página de configurações de conta.',
  'Only include spaces below to the mail summary' => 'Somente inclua espaços abaixo do resumo do e-mail',
  'Reset to defaults' => 'Redefinir para o padrão',
  'See online:' => 'Ver online:',
  'Spaces' => 'Espaços',
  'There are no activities yet.' => 'Não há atividades ainda.',
  'Weekly' => 'Semanalmente',
  'You will only receive an e-mail if there is something new.' => 'Você só receberá um e-mail se tiver algo novo.',
  'Your daily summary' => 'Seu resumo diário',
  'Your monthly summary' => 'Seu resumo mensal',
  'Your weekly summary' => 'Seu resumo semanal',
  'see online' => 'ver online',
  'via' => 'via',
  '{displayName} created the new space {spaceName}' => '{displayName} criou o novo espaço {spaceName}',
  '{displayName} created this space.' => '{displayName} criou este espaço.',
  '{displayName} joined the space {spaceName}' => '{displayName} entrou no espaço {spaceName}',
  '{displayName} joined this space.' => '{displayName} entrou neste espaço.',
  '{displayName} left the space {spaceName}' => '{displayName} deixou o espaço {spaceName}',
  '{displayName} left this space.' => '{displayName} deixou este espaço.',
  '{spaceName} has been archived' => '{spaceName} foi arquivado',
  '{spaceName} has been unarchived' => '{spaceName} foi desarquivado',
  '{user1} now follows {user2}.' => '{user1} agora segue {user2}.',
);

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/activity/messages/pt-BR/base.php <==
<?php
return [
  '<strong>E-Mail</strong> Summaries' => '<strong>E-Mails</strong> de resumo',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> atividades',
  'Activities' => 'Atividades',
  'Daily' => 'Diariamente',
  'E-Mail Summaries' => 'E-mails de resumo',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'E-mails de resumo são enviados para informá-lo sobre atividades recentes na rede.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'E-mails de resumo são enviados para os usuários para informá-los sobre atividades recentes em sua rede.',
  'Exclude spaces below from the mail summary' => 'Exclua espaços abaixo do resumo do e-mail',
  'Hourly' => 'De hora em hora',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas notícias',
  'Monthly' => 'Mensal',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Nessa página você pode configurar os conteúdos e o intervalo das atualizações de e-mail.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Nessa página você pode definir o comportamento padrão para seus usuários. Essas configurações podem ser sobrescritas pelos usuários na página de configurações de conta.',
  'Only include spaces below to the mail summary' => 'Somente inclua espaços abaixo do resumo do e-mail',
  'Reset to defaults' => 'Redefinir para o padrão',
  'See online:' => 'Ver online:',
  'Spaces' => 'Espaços',
  'There are no activities yet.' => 'Não há atividades ainda.',
  'Weekly' => 'Semanalmente',
  'You will only receive an e-mail if there is something new.' => 'Você só receberá um e-mail se tiver algo novo.',
  'Your daily summary' => 'Seu resumo diário',
  'Your monthly summary' => 'Seu resumo mensal',
  'Your weekly summary' => 'Seu resumo semanal',
  'see online' => 'ver online',
  'via' => 'via',
  '{displayName} created the new space {spaceName}' => '{displayName} criou o espaço {spaceName}',
  '{displayName} created this space.' => '{displayName} criou este espaço.',
  '{displayName} joined the space {spaceName}' => '{displayName} entrou no espaço {spaceName}',
  '{displayName} joined this space.' => '{displayName} entrou neste espaço.',
  '{displayName} left the space {spaceName}' => '{displayName} deixou o espaço {spaceName}',
  '{displayName} left this space.' => '{displayName} deixou este espaço.',
  '{spaceName} has been archived' => '{spaceName} foi arquivado',
  '{spaceName} has been unarchived' => '{spaceName} foi desarquivado',
  '{user1} now follows {user2}.' => '{user1} está seguindo {user2}',
];
